@@ -359,7 +359,9 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             # set session timeout 10 times greater than health-check
             session_timeout_ms=self.session_timeout,
             heartbeat_interval_ms=self.settings.health_check_ms,
-            consumer_timeout_ms=self.settings.request_timeout_ms
+            consumer_timeout_ms=self.settings.request_timeout_ms,
+            # request timeout must be greater than session timeout
+            request_timeout_ms=self.session_timeout*2
         )
         self.logger.debug("consumer created")
         try:
@@ -447,5 +449,6 @@ class AssignKafkaSubscriber(AsyncKafkaSubscriber):
             await super().commit(task, timeout)
         else:
             # no commits if no consumer group, just resume paused TP
-            tp, _ = self._get_message_meta(task)
+            assert 'kafka_subscriber' in task._local, "cannot commit task not received by this subscriber"
+            tp = TopicPartition(task._local['kafka_subscriber'][0], task._local['kafka_subscriber'][1])
             self._resume_partition(tp)
